Installation
============

korona requires Python 2.7 or 3.3+.

To install from `PyPI <https://pypi.python.org/pypi/korona>`_:

::

    pip install korona


You can also install korona with all the latest changes:

::

    $ git clone git@github.com:bharadwajyarlagadda/korona.git
    $ cd korona
    $ python setup.py install

